# Path to the directory that contains the GCC tools used to build
# frysk; and any version suffix.  If you're using a custom compiler
# modify this.

%define frysk_gcc_prefix /usr/bin/
%define frysk_gcc_suffix 4

# Sometimes just the libraries are wanted; sometimes not everything
# builds.  Provide fine grained control.

%define build_antlr 1
%define build_frysk 1

#---- cairo/fontconfig/pango defines
%define freetype_version 2.1.5
#---- pango defines
%define pkgconfig_version 0.12
%define xft_version 1.9.1.020626.1517-1
#---- gtk2 defines
%define _unpackaged_files_terminate_build      1
%define _missing_doc_files_terminate_build     1
%define libpng_version 2:1.2.2-16

Summary:	Frysk execution analysis tool
Name:		frysk
Version:	0.0.1.2006.01.22
Release:	0.EL4.0
License:	GPL + EXPLICIT EXCEPTION
Group:		Development/System
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
URL:		http://sourceware.org/frysk

%define frysk %{name}-%{version}
Source0:	%{name}-%{version}.tar.bz2

%define antlr_version 2.7.5
%define antlr antlr-%{antlr_version}
Source100:	%{antlr}.tar.gz
Patch101:	antlr.patch

%define atk_version 1.11.2
%define atk atk-%{atk_version}
Source200:	%{atk}.tar.bz2

%define cairo_version 1.0.2
%define cairo cairo-%{cairo_version}
Source300:	%{cairo}.tar.gz

%define cairo_java_version 1.0.2
%define cairo_java cairo-java-%{cairo_java_version}
Source400:	%{cairo_java}.tar.gz
# frysk local: frysk-2022: allow overriding of datadir (containing .jars)
Patch499:	cairo-java-pkg-dir.patch

%define fontconfig_version 2.3.93
%define fontconfig fontconfig-%{fontconfig_version}
Source500:	%{fontconfig}.tar.gz
# see -install
Source501:	40-blacklist-fonts.conf
Source502:	50-no-hint-fonts.conf
Patch501:	fontconfig-2.3.93-defaultconfig.patch
Patch502:	fontconfig-2.3.91-crosscheck.patch

%define glib2_version 2.9.4
%define glib2 glib-%{glib2_version}
Source600:	%{glib2}.tar.bz2
Source602:	glib2.sh
Source603:	glib2.csh

%define glib_java_version 0.2.2
%define glib_java glib-java-%{glib_java_version}
Source700:	%{glib_java}.tar.gz
# frysk local: frysk-2144: replace hard-wired <<gcj>> with $GCJ
Patch790:	glib-java-macro.patch
# frysk local: frysk-2022: allow overriding of datadir (containing .jars)
Patch799:	glib-java-pkg-dir.patch

%define gtk2_version 2.8.10
%define gtk2 gtk+-%{gtk2_version}
Source800:	%{gtk2}.tar.bz2
# Biarch changes
Patch800:	gtk+-2.4.1-lib64.patch
# Backported from 2.10
Patch801:	gtk+-2.8.6-inputmethod.patch
Patch802:	gtk+-2.8.10-abicheck.patch
Patch803:	gtk+-2.8.10-set-invisible-char-to-bullet.patch
# frysk local: just assume glib and pango
Patch890:	gtk+-skip-glib-check.patch
Patch891:	gtk+-skip-pango-check.patch
# frysk local: pass -lm
Patch892:	gtk+-libgdk-lm.patch
# frysk local: frysk-2031: Try to make themes work
Patch894:	gtk+-2.8.6-frysk-theme-fix.patch

%define libgtk_java_version 2.8.2
%define libgtk_java libgtk-java-%{libgtk_java_version}
Source900:	%{libgtk_java}.tar.gz
# frysk local: frysk-2022: allow overriding of datadir (containing .jars)
Patch999:	libgtk-java-pkg-dir.patch

%define libglade2_version 2.5.1
%define libglade2 libglade-%{libglade2_version}
Source1100:	%{libglade2}.tar.bz2
# http://bugzilla.gnome.org/show_bug.cgi?id=121025
Patch1101: libglade-2.0.1-nowarning.patch

%define libglade_java_version 2.12.1
%define libglade_java libglade-java-%{libglade_java_version}
Source1200:	%{libglade_java}.tar.gz
# frysk local: frysk-2022: allow overriding of datadir (containing .jars)
Patch1299:	libglade-java-pkg-dir.patch

%define pango_version 1.11.2
%define pango pango-%{pango_version}
Source1300:	%{pango}.tar.bz2
Patch1301:	pango-slighthint.patch
# Look for pango.modules in an arch-specific directory
Patch1305:	pango-1.2.5-lib64.patch
# frysk local: frysk-local: assume cairo
Patch1390:	pango-skip-cairo-check.patch

%define libvte_java_version 0.11.11
%define libvte_java libvte-java-%{libvte_java_version}
Source1500:	%{libvte_java}.tar.gz
# frysk local: Allow libgnomeui 2.8.0 instead of 2.9.1
Patch1590:	libvte-java-frysk-libgnomeui-canvas-version-fix.patch
# frysk local: frysk-2022: allow overriding of datadir (containing .jars)
Patch1599:	libvte-java-pkg-dir.patch

%define jdom_version 1.0
%define jdom jdom-%{jdom_version}
Source1600:	%{jdom}.tar.gz
# frysk local: List of files to compile.
Patch1690:	jdom-files.patch
# frysk local: Hacks to get around broken GCJ
Patch1691:	jdom-compiler.patch

# frysk
BuildRequires: make
BuildRequires: transfig
BuildRequires: gcc4 gcc4-java gcc4-c++
BuildRequires: autoconf automake automake17
#---- glib2
BuildRequires: /sbin/ldconfig
#---- gtk2
BuildRequires: XFree86-devel
BuildRequires: gtk-doc
BuildRequires: libtiff-devel
BuildRequires: libjpeg-devel
#---- libglade
BuildRequires: libxml2 >= 2.4.10
#---- glib2
BuildRequires: gettext
#---- cairo
BuildRequires: pkgconfig
BuildRequires: xorg-x11-devel
BuildRequires: libpng-devel
BuildRequires: freetype-devel >= %{freetype_version}
#---- fontconfig
BuildRequires: expat-devel
BuildRequires: perl
BuildRequires: docbook-utils-pdf >= 0.6.14
BuildRequires: elinks >= 0.9.2
#---- pango
BuildRequires: libtool >= 1.4.2-10
BuildRequires: pkgconfig >= %{pkgconfig_version}
BuildRequires: freetype-devel >= %{freetype_version}
BuildRequires: xorg-x11-devel >= 4.2.99
BuildRequires: pkgconfig
#---- vte-java
BuildRequires: vte-devel libgnomeui-devel libgnomecanvas
Requires: vte

# Limit build to i386 ...
ExclusiveArch: %{ix86}

%description
Frysk is an execution-analysis technology implemented using native Java and C++.
It is aimed at providing developers and sysadmins with the ability to both
examine and analyze running multi-host, multi-process, multi-threaded systems.
Frysk allows the monitoring of running processes and threads, of locking
primitives and will also expose deadlocks, gather data and debug any given
process in the system.


%prep

# -nNAME: Set unpack-directory to NAME (default %{name}-%{version})
# -q: Quiet, a must have!
# -T: disable default unpacking of first TAR ball.
# -b#: Unpack Source# AND-THEN cd into unpack-directory
# -c: create (and cd to) unpack-directory before proceeding
# -a#: cd into unpack-directory and then unpack Source#
# -D: disable default of first deleting unpack-directory

%setup -n %{frysk} -q -T -b0
./autogen.sh

%setup -n %{glib2} -q -T -b600

# Unpack glib-java early; other java packages use this packages m4
# macros.
%setup -n %{glib_java} -q -T -b700
%patch790 -p1 -b .macro
%patch799 -p1 -b .pkg-dir
aclocal -I macros
autoconf
automake

%setup -n %{fontconfig} -q -T -b500
%patch501 -p1 -b .defaultconfig
%patch502 -p1 -b .crosscheck

%setup -n %{atk} -q -T -b200

%setup -n %{cairo} -q -T -b300

%setup -n %{cairo_java} -q -T -b400
%patch499 -p1 -b .pkg-dir
aclocal -I ../%{glib_java}/macros
autoconf
automake

%setup -n %{pango} -q -T -b1300
%patch1301 -p1 -b .slighthint
%patch1305 -p1 -b .lib64
%patch1390 -p2 -b .skip-cairo-check
autoconf
automake-1.7

%setup -n %{gtk2} -q -T -b800
%patch800 -p1 -b .lib64
%patch801 -p1 -b .inputmethod
%patch802 -p1 -b .abicheck
%patch803 -p1 -b .set-invisible-char-to-bullet
# %patch890 -p2 -b .skip-glib-check
%patch891 -p0 -b .skip-pango-check
%patch892 -p0 -b .libgdk-lm
%patch894 -p0 -b .frysk-theme-fix
libtoolize --force
# Patch5 modifies gdk-pixbuf/Makefile.am
aclocal-1.7
automake-1.7
autoconf

%setup -n %{libgtk_java} -q -T -b900
%patch999 -p1 -b .pkg-dir
aclocal -I ../%{glib_java}/macros
autoconf
automake

%setup -n %{libglade2} -q -T -b1100
%patch1101 -p1 -b .nowarning
# aclocal -I m4 -I macros
# autoconf

%setup -n %{libglade_java} -q -T -b1200
%patch1299 -p1 -b .pkg-dir
aclocal -I ../%{glib_java}/macros -I ../%{libgtk_java}/macros
autoconf
automake

%setup -n %{libvte_java} -q -T -b1500
%patch1590 -p0 -b .canvas-version-fix
%patch1599 -p1 -b .pkg-dir
aclocal -I ../%{glib_java}/macros -I ../%{libgtk_java}/macros
autoconf
automake

%setup -n %{antlr} -q -T -b100
%patch101 -p2
# frysk local: Antlr's config.* is really really old.
for i in $(find . -name config.guess -o -name config.sub) ; do
   [ -f /usr/lib/rpm/redhat/$(basename $i) ] && %{__rm} -f $i && %{__cp} -fv /usr/lib/rpm/redhat/$(basename $i) $i
done

%setup -n %{jdom} -q -T -b1600
%patch1690 -p0
%patch1691 -p1 -b .compiler

# Finish up back in in the frysk sub directory, so that build starts
# there.
%setup -D -q -T -c

%build

# %define BUILDDIR	$RPM_BUILD_DIR/build-%{name}-%{version}-%{release}-%{_target_platform}
%define BUILDDIR	$RPM_BUILD_DIR/build-%{name}-%{version}
%define DESTDIR		$RPM_BUILD_ROOT
%define destdir DESTDIR = %{DESTDIR}

# We have to prevent the standard dependency generation from identifying
# our private libraries in our provides and requires.
%define _use_internal_dependency_generator	0
%define __find_provides /bin/sh -c '/usr/lib/rpm/find-provides | tee frysk.provides | fgrep frysk'
%define __find_requires /bin/sh -c '/usr/lib/rpm/find-requires | fgrep -v -f frysk.provides'

# In case the previous build failed
echo Deleting the install tree ...
rm -rf $RPM_BUILD_ROOT
rm -rf %{BUILDDIR}
echo ... use make install-short

%install

echo $RPM_BUILD_ROOT

# Hey, were's this script being run?
pwd

# Set configure options that will install into frysk special locations
# under /usr.  frysk-gtk is slightly different, it installs lib/ and
# include/ files into sub-directories so that they do not thwack the
# existing installed stuff.

%define _prefix		/usr
%define _sysconfdir	/etc/frysk
%define _sharedstatedir	%{_prefix}/com/frysk
%define _localstatedir	%{_prefix}/var/frysk

%define __frysk_datadir		%{_prefix}/share/frysk
%define __frysk_libdir		%{_prefix}/%{_lib}/frysk
%define __frysk_includedir	%{_prefix}/include/frysk

%define __frysk_configure --build=%{_build} --host=%{_host} --target=%{_target_platform} --program-prefix=%{?_program_prefix} --prefix=%{_prefix} --exec-prefix=%{_exec_prefix} --bindir=%{_bindir} --sbindir=%{_sbindir} --sysconfdir=%{_sysconfdir} --datadir=%{_datadir} --includedir=%{_includedir} --libdir=%{_libdir} --libexecdir=%{_libexecdir} --localstatedir=%{_localstatedir} --sharedstatedir=%{_sharedstatedir} --mandir=%{_mandir} --infodir=%{_infodir}

%define __frysk_libs_configure %{__frysk_configure} --libdir=%{__frysk_libdir} --includedir=%{__frysk_includedir} --datadir=%{__frysk_datadir} --program-prefix=frysk-

# export LD_LIBRARY_PATH and PKG_CONFIG_PATH

export PKG_CONFIG_PATH=$RPM_BUILD_ROOT/%{__frysk_libdir}/pkgconfig:%{_libdir}/pkgconfig
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{__frysk_libdir}

#----------------------------------------------------------------------

# Some build magic; CONFIGURE, BUILD, and INSTALL each check to see if
# they have previously already run and if they have, skip.  Makes
# install-short very efficient.

# Force the GCC-4 version of all tools (don't want this being confused
# by optional rpms such as eclipse-ecj).  The absolute path is
# required as otherwize AC_PATH_PROG ignores the environment variable
# (AC_PATH_PROGS doesn't appear to suffer from this bug, sigh!

EXPORT ()
{
	local p=%{frysk_gcc_prefix}
	local s=%{frysk_gcc_suffix}
%ifarch ppc64
	local c=" -mminimal-toc"
%else
	local c=""
%endif
	echo export RPM_BUILD_ROOT=$RPM_BUILD_ROOT
	echo export RPM_BUILD_DIR=$RPM_BUILD_DIR
	echo export \'JAVAC=${JAVAC:-${p}gcj${s} -C${c}}\'
	echo export \'GCJ=${GCJ:-${p}gcj${s}${c}}\'
	echo export \'GIJ=${GIJ:-${p}gij${s}}\'
	echo export \'JAR=${JAR:-${p}fastjar${s}}\'
	echo export \'GCJH=${GCJH:-${p}gcjh${s}}\'
	echo export \'GCJ_DBTOOL=${GCJ_DBTOOL:-${p}gcj-dbtool${s}}\'
	echo export \'GCC=${GCC:-${p}gcc${s}${c}}\'
	echo export \'CC=${CC:-${p}gcc${s}${c}}\'
	echo export \'CXX=${CXX:-${p}g++${s}${c}}\'
	echo export \'JAVA=${JAVA:-${p}gij${s}}\'
	echo export \'JV_SCAN=${JV_SCAN:-${p}jv-scan${s}}\'
	echo export PKG_CONFIG_PATH=${PKG_CONFIG_PATH:-$RPM_BUILD_ROOT/%{__frysk_libdir}/pkgconfig:%{_libdir}/pkgconfig}
	echo export LD_LIBRARY_PATH=${LD_LIBRARY_PATH:-$RPM_BUILD_ROOT/%{__frysk_libdir}}
}

MKSCRIPT ()
{
	local c=$1 ; shift
	local d=$1 ; shift
	local script=%{BUILDDIR}/$c.$d
	mkdir -p `dirname ${script}`
	rm -f ${script}
	touch ${script}
	chmod a+x ${script}
	echo '#!/bin/sh -xe' >> ${script}
	echo mkdir -p %{BUILDDIR}/$d >> ${script}
	echo cd %{BUILDDIR}/$d >> ${script}
 	EXPORT >> ${script}
	echo ${script}
}

ECHO_CMD ()
{
	local arg
	for arg in "$@" ; do
		echo \'"${arg}"\' \\
	done
	echo '"$@"'
}

# REQUIRES <package> <dependencies>

REQUIRES ()
{
	local d=$1 ; shift
	CONFIG_P && return # if not configured skip
	for i in "$@" x ; do
		test $i = x && continue
		for j in CONFIGURED BUILT INSTALLED ; do
			if test ! -r %{BUILDDIR}/$i/$j -o %{BUILDDIR}/$i/$j -nt %{BUILDDIR}/$d/CONFIGURED ; then
				rm -f %{BUILDDIR}/$d/CONFIGURED
				return
			fi
		done
	done
}

CONFIG_P ()
{
	test ! -r %{BUILDDIR}/$1/CONFIGURED
}

CONFIGURED ()
{
	touch %{BUILDDIR}/$1/CONFIGURED
}

CONFIG ()
{
	local d=$1 ; shift
	if CONFIG_P $d ; then
		rm -f %{BUILDDIR}/$d/BUILT
		rm -f %{BUILDDIR}/$d/INSTALLED
		local script=`MKSCRIPT CONFIG $d`
		ECHO_CMD ${RPM_BUILD_DIR}/$d/configure "$@" >> ${script}
		${script}
		CONFIGURED $d
	fi
}

BUILD_P ()
{
	test ! -r %{BUILDDIR}/$1/BUILT
}

BUILT ()
{
	touch %{BUILDDIR}/$1/BUILT
}

BUILD ()
{
	local d=$1 ; shift
	if BUILD_P $d ; then
		rm -f %{BUILDDIR}/$d/INSTALLED
		local script=`MKSCRIPT BUILD $d`
		ECHO_CMD make "$@" >> ${script}
		${script}
		BUILT $d
	fi
}

INSTALL_P ()
{
	test ! -r %{BUILDDIR}/$1/INSTALLED
}

INSTALLED ()
{
	touch %{BUILDDIR}/$1/INSTALLED
}

INSTALL ()
{
	local d=$1 ; shift
	local script=%{BUILDDIR}/INSTALL/$d
	if INSTALL_P $d ; then
		local script=`MKSCRIPT INSTALL $d`
		ECHO_CMD make install "DESTDIR = %{DESTDIR}" "$@" >> ${script}
		${script}
		INSTALLED $d
	fi
}

# Generate a script that runs program ($1) writing the output into the
# file ($2).  Also install a dummy version of the file so that it is
# included in the rpm manifest and hence is automatically removed when
# the rpm is removed; doing that avoids the need for a -postun step
# that removes the file.

MKUPDATE ()
{
	local name=$1 ; shift
	local query=%{_bindir}/$1 ; shift
	local file=%{_sysconfdir}/$1 ; shift
	local script=$RPM_BUILD_ROOT%{_bindir}/${name}
	# Create the script
	mkdir -p `dirname ${script}`
	rm -f ${script}
	touch ${script}
	chmod u=rwx,go=rx ${script}
	echo '#!/bin/sh'                  >> ${script}
	echo "mkdir -p `dirname ${file}`" >> ${script}
	echo "${query} > ${file}"         >> ${script}
	# Create the scratch file
	mkdir -p `dirname $RPM_BUILD_ROOT${file}`
	rm -f $RPM_BUILD_ROOT${file}
	touch $RPM_BUILD_ROOT${file}
	chmod u=rw,go=r $RPM_BUILD_ROOT${file}
	echo '# Generated file; to regenerate:' >> $RPM_BUILD_ROOT${file}
	sed -e 's/^/#/' ${script}               >> $RPM_BUILD_ROOT${file}
}


#-------------glib2----------------------------------------

%define glib2_builddir %{BUILDDIR}/%{glib2}

CONFIG %{glib2} \
	--disable-gtk-doc \
	--enable-static \
	%{__frysk_libs_configure}
BUILD %{glib2} \
	%{?_smp_mflags}
INSTALL %{glib2}

%define GLIB_CFLAGS -pthread -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/glib-2.0/include
%define glib_cflags GLIB_CFLAGS = %{GLIB_CFLAGS}

%define lib_gobject %{glib2_builddir}/gobject/libgobject-2.0.la
%define lib_gmodule %{glib2_builddir}/gmodule/libgmodule-2.0.la
%define lib_gthread %{glib2_builddir}/gthread/libgthread-2.0.la
%define lib_glib %{glib2_builddir}/glib/libglib-2.0.la

#------------glib-java-------------------------------------

%define glib_java_builddir %{BUILDDIR}/%{glib_java}

%define glib_java_makeflags "%{glib_cflags}" "GLIB_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}"

if CONFIG_P %{glib_java} ; then
	CONFIG %{glib_java} \
		--without-javadocs \
		%{__frysk_libs_configure}
	# FIXME: find a better solution for this
	pushd %{BUILDDIR}/%{glib_java}
	sed -i 's/^pic_flag=\"\"/pic_flag=\"\ \-fPIC\"/' libtool
	sed -i 's/^compiler_c_o=\"no\"/compiler_c_o=\"yes\"/' libtool
	popd
fi
BUILD %{glib_java} %{?_smp_mflags} %{glib_java_makeflags}
INSTALL %{glib_java}

%define JGJAVA_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-java
%define jgjava_cflags JGJAVA_CFLAGS = %{JGJAVA_CFLAGS}
%define GLIB_JAVA_CFLAGS %{JGJAVA_CFLAGS}

%define JGJAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/glib0.2-0.2.2.jar
%define jgjar JGJAR = %{JGJAR}
%define GLIB_JAVA_JAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/glib0.2-0.2.2.jar

%define lib_glibjava %{glib_java_builddir}/libglibjava.la
%define lib_glibjni %{glib_java_builddir}/libglibjni.la

#-------------fontconfig-----------------------------------

%define fontconfig_builddir %{BUILDDIR}/%{fontconfig}

# Work around weird elinks bug where elinks refuses to open the
# temporary html file generated by jade because it thinks it's a
# special file.  Only happens in beehive.
export ELINKS_CONFDIR=$PWD/elinks-conf
mkdir -p $ELINKS_CONFDIR
echo "set protocol.file.allow_special_files = 1" > $ELINKS_CONFDIR/elinks.conf

CONFIG %{fontconfig} \
	--with-add-fonts=/usr/X11R6/lib/X11/fonts/Type1,/usr/X11R6/lib/X11/fonts/OTF \
	%{__frysk_libs_configure}
BUILD %{fontconfig} %{?_smp_mflags}
if INSTALL_P %{fontconfig} ; then
	INSTALL %{fontconfig}
	install -m 0644 %{SOURCE501} $RPM_BUILD_ROOT%{_sysconfdir}/fonts/conf.d
	install -m 0644 %{SOURCE502} $RPM_BUILD_ROOT%{_sysconfdir}/fonts/conf.d
	rm $RPM_BUILD_ROOT%{__frysk_libdir}/*.la
	rm $RPM_BUILD_ROOT%{_localstatedir}/cache/fontconfig/stamp
fi

%define lib_fontconfig %{fontconfig_builddir}/src/libfontconfig.la

#------------atk-------------------------------------------

%define atk_makeflags "DEP_CFLAGS = %{GLIB_CFLAGS}" "DEP_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_glib}"

%define atk_builddir %{BUILDDIR}/%{atk}

CONFIG %{atk} \
	--disable-glibtest \
	--disable-gtk-doc \
	%{__frysk_libs_configure}
BUILD %{atk} %{?_smp_mflags} %{atk_makeflags}
INSTALL %{atk}

%define ATK_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/atk-1.0
%define lib_atk %{atk_builddir}/atk/libatk-1.0.la

#------------cairo-----------------------------------------

%define cairo_builddir %{BUILDDIR}/%{cairo}

CONFIG %{cairo} \
	--enable-warnings \
	--disable-glitz \
	--disable-quartz \
        --disable-atsui \
	--disable-xcb \
	--disable-win32 \
        --disable-gtk-doc \
	%{__frysk_libs_configure}
BUILD %{cairo} %{?_smp_mflags}
INSTALL %{cairo}

%define CAIRO_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo -I$RPM_BUILD_ROOT/%{__frysk_includedir}
%define cairo_cflags CAIRO_CFLAGS = %{CAIRO_CFLAGS}

%define lib_cairo %{cairo_builddir}/src/libcairo.la

#------------cairo-java------------------------------------

%define cairo_java_builddir %{BUILDDIR}/%{cairo_java}

%define cairo_java_makeflags "%{glib_cflags}" "GLIB_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}" "%{cairo_cflags}" "CAIRO_LIBS = %{lib_cairo}" "%{jgjava_cflags}" "JGJAVA_LIBS = %{lib_glibjava}" "JGJNI_LIBS = %{lib_glibjni}" "%{jgjar}"

CONFIG %{cairo_java} \
	--without-javadocs \
	%{__frysk_libs_configure}
BUILD %{cairo_java} %{?_smp_mflags} %{cairo_java_makeflags}
INSTALL %{cairo_java}

%define CAIROJAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/cairo1.0-1.0.2.jar
%define cairojar CAIROJAR = %{CAIROJAR}

%define CAIRO_JAVA_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-java
%define cairo_java_cflags CAIRO_JAVA_CFLAGS = %{CAIRO_JAVA_CFLAGS}

%define lib_cairojava %{cairo_java_builddir}/libcairojava.la

#------------pango-----------------------------------------

%define pango_makeflags "%{glib_cflags}" "%{cairo_cflags}" "FONTCONFIG_LIBS = %{lib_fontconfig}" "GLIB_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}" "CAIRO_LIBS = %{lib_cairo}" "XFT_CFLAGS = -I$RPM_BUILD_ROOT/%{__frysk_includedir} -I/usr/X11R6/include -I/usr/include/freetype2 -I/usr/include/freetype2/config" "XFT_LIBS = -L/usr/X11R6/%{_lib} -lXft -lX11 -lfreetype -lXrender %{lib_fontconfig}"

%define pango_builddir %{BUILDDIR}/%{pango}

CONFIG %{pango} \
	%{__frysk_libs_configure}
BUILD %{pango} %{?_smp_mflags} %{pango_makeflags}
if INSTALL_P ; then
	# NOTE: XXX: The below uses _host, rather than the correct
	# _target_platform.  This is because pango wires a path
	# containing the HOST, and not the TARGET, into the
	# executable.
	MKUPDATE frysk-update-pango-modules frysk-pango-querymodules pango/%{_host}/pango.modules
	INSTALL %{pango} %{pango_makeflags}
fi

%define PANGO_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/pango-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}
%define pango_cflags PANGO_CFLAGS = %{PANGO_CFLAGS}

%define lib_pango %{pango_builddir}/pango/libpango-1.0.la
%define lib_pangocairo %{pango_builddir}/pango/libpangocairo-1.0.la
%define lib_pangoft2 %{pango_builddir}/pango/libpangoft2-1.0.la
%define lib_pangox %{pango_builddir}/pango/libpangox-1.0.la
%define lib_pangoxft %{pango_builddir}/pango/libpangoxft-1.0.la

#------------gtk2------------------------------------------

%define gtk2_makeflags "GDK_PIXBUF_DEP_CFLAGS = %{GLIB_CFLAGS} -I/usr/include/libpng12" "GDK_PIXBUF_DEP_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}" "GDK_DEP_CFLAGS = -DXTHREADS -D_REENTRANT -DXUSE_MTSAFE_API %{GLIB_CFLAGS} %{CAIRO_CFLAGS} %{PANGO_CFLAGS}" "GDK_DEP_LIBS = -L/usr/X11R6/%{_lib} -lXrandr -lXrender -lXi -lXinerama -lXext -lX11 %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib} %{lib_fontconfig} -ldl -lXcursor -lXrender -lXext -lXfixes -lX11 -lm" "GTK_DEP_CFLAGS = %{GLIB_CFLAGS} %{PANGO_CFLAGS} %{CAIRO_CFLAGS} %{ATK_CFLAGS}" "GTK_DEP_LIBS = -L/usr/X11R6/%{_lib} -lX11 %{lib_pangocairo} %{lib_pango} %{lib_atk} %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib} %{lib_cairo} -ldl -lm" "%{glib_cflags}" "GLIB_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}" "%{cairo_cflags}" "GDK_PIXBUF_XLIB_DEP_CFLAGS = %{GLIB_CFLAGS} -I/usr/X11R6/include"

%define gtk2_builddir %{BUILDDIR}/%{gtk2}

CONFIG %{gtk2} \
	--disable-glibtest \
	--with-xinput=xfree \
	--disable-gtk-doc \
	%{__frysk_libs_configure}
## smp_mflags doesn't work for now due to gdk-pixbuf.loaders, may be fixed
## past gtk 2.1.2
# make # %{?_smp_mflags}
BUILD %{gtk2} %{gtk2_makeflags}
if INSTALL_P ; then
	MKUPDATE frysk-update-gdk-pixbuf-loaders frysk-gdk-pixbuf-query-loaders gtk-2.0/gdk-pixbuf.loaders
	# NOTE: XXX: Because a patch hardwires GTK_LIB to /usr/lib
	# instead of /usr/lib/frysk, this generates paths that point
	# to the existing / installed immodules. XXX: Per rant with
	# pango's MKUPDATE call, _host should be _target_platform.
	MKUPDATE frysk-update-gtk-immodules frysk-gtk-query-immodules-2.0 gtk-2.0/%{_host}/gtk.immodules
	INSTALL %{gtk2} %{gtk2_makeflags}
fi

%define GTK_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/gtk-2.0/include

%define lib_gdk_x11 %{gtk2_builddir}/gdk/libgdk-x11-2.0.la
%define lib_gdk_pixbuf %{gtk2_builddir}/gdk-pixbuf/libgdk_pixbuf-2.0.la
%define lib_gtk_x11 %{gtk2_builddir}/gtk/libgtk-x11-2.0.la

#------------libgtk-java-----------------------------------

%define libgtk_java_builddir %{BUILDDIR}/%{libgtk_java}

%define libgtk_java_makeflags "%{glib_cflags}" "GLIB_LIBS = %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib}" "%{cairo_cflags}" "CAIRO_LIBS = %{lib_cairo}" "%{jgjava_cflags}" "JGJAVA_LIBS = %{lib_glibjava}" "JGJNI_LIBS = %{lib_glibjni}" "%{jgjar}" "%{cairo_java_cflags}" "CAIRO_JAVA_LIBS = %{lib_cairojava}" "%{cairojar}" "GTK_CFLAGS = %{GTK_CFLAGS} %{GLIB_CFLAGS} %{ATK_CFLAGS} %{PANGO_CFLAGS}" "GTK_LIBS = -ldl %{lib_gdk_x11} %{lib_gdk_pixbuf} %{lib_gobject} %{lib_gmodule} %{lib_glib} %{lib_atk} %{libgpango} %{lib_pangocairo}" "ATK_CFLAGS = %{ATK_CFLAGS}" "ATK_LIBS = %{lib_atk}" "GTHREAD_CFLAGS = %{GLIB_CFLAGS}" "GTHREAD_LIBS = %{lib_gthread} %{lib_glib}"

CONFIG %{libgtk_java} \
	--without-javadocs \
	%{__frysk_libs_configure}
BUILD %{libgtk_java} %{?_smp_mflags} %{libgtk_java_makeflags}
INSTALL %{libgtk_java}

%define GTKJAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/gtk2.8-2.8.2.jar
%define gtkjar GTKJAR = %{GTKJAR}
%define GTK2_JAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/gtk2.8-2.8.2.jar

%define GTKJAVA_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/libgtk-java -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-java -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo -I$RPM_BUILD_ROOT/%{__frysk_libdir}/gtk-2.0/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/atk-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/pango-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/glib-2.0/include
%define gtkjava_cflags GTKJAVA_CFLAGS = %{GTKJAVA_CFLAGS}

%define lib_gtk_java %{libgtk_java_builddir}/libgtkjava.la
%define lib_gtkjni %{libgtk_java_builddir}/libgtkjni.la

#------------libglade2--------------------------------------

%define libglade2_makeflags "LIBGLADE_CFLAGS = %{GLIB_CFLAGS} %{GTK_CFLAGS} %{CAIRO_CFLAGS} %{PANGO_CFLAGS} -I/usr/include/libxml2 %{ATK_CFLAGS}" "LIBGLADE_LIBS = -Wl,--export-dynamic -lxml2 -lpthread -lz %{lib_gtk_x11} %{lib_gdk_x11} %{lib_gdk_pixbuf} %{lib_atk} -lm %{lib_pangocairo} %{lib_pangoft2} %{lib_pango} %{lib_cairo} %{lib_gobject} %{lib_gmodule} %{lib_gthread} %{lib_glib} -ldl"

%define libglade2_builddir %{BUILDDIR}/%{libglade2}

CONFIG %{libglade2} \
	--without-javadocs \
	--disable-gtktest \
	--without-gnome \
	%{__frysk_libs_configure}
BUILD %{libglade2} %{?_smp_mflags} %{libglade2_makeflags}
INSTALL %{libglade2}

%define LIBGLADE_CFLAGS -I$RPM_BUILD_ROOT/%{__frysk_includedir}/libglade-2.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/atk-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo -I$RPM_BUILD_ROOT/%{__frysk_includedir}/pango-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0/include -I/usr/include/libxml
%define libglade_cflags LIBGLADE_CFLAGS = %{LIBGLADE_CFLAGS}

%define lib_glade %{libglade2_builddir}/glade/libglade-2.0.la

#------------libglade-java---------------------------------

# REQUIRES: libgtk-java

%define libglade_java_builddir %{BUILDDIR}/%{libglade_java}

%define libglade_java_makeflags %{libgtk_java_makeflags} "%{libglade_cflags}" "LIBGLADE_LIBS = %{lib_glade} %{libgtk} %{lib_atk} %{lib_cairo} %{lib_gdk_x11} %{lib_gdk_x11_pixbuf} %{lib_pangocairo} %{lib_pango} %{lib_gobject} %{lib_gmodule} %{lib_glib}" "%{gtkjar}" "%{gtkjava_cflags}" "GTKJAVA_LIBS = %{lib_gtk_java} %{lib_cairojava} %{lib_glibjava} %{lib_gdk_x11} %{lib_atk} %{lib_gdk_x11_pixbuf} %{lib_pangocairo} %{lib_pango} %{lib_cairo} %{lib_gobject} %{lib_gmodule} -ldl %{lib_glib} %{lib_gtk_x11}" "GTKJNI_LIBS = %{lib_gtkjni}"

CONFIG %{libglade_java} \
	--without-gnome \
	--without-javadocs \
	%{__frysk_libs_configure}
BUILD %{libglade_java} %{?_smp_mflags} %{libglade_java_makeflags}
INSTALL %{libglade_java}

%define GLADE_JAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/glade2.12.jar

#------------libvte-java-----------------------------------

%define libvte_java_builddir %{BUILDDIR}/%{libvte_java}

%define libvte_java_makeflags %{libglade_java_makeflags} "GNOME_CFLAGS = -pthread -DORBIT2=1 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/glib-2.0/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/pango-1.0 -I/usr/include/ -I/usr/include/freetype2 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/gtk-2.0/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/atk-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo -I/usr/include/libgnomeui-2.0 -I/usr/include/libgnome-2.0 -I/usr/include/libgnomecanvas-2.0 -I/usr/include/libart-2.0 -I/usr/include/gconf/2 -I/usr/include/libbonoboui-2.0 -I/usr/include/orbit-2.0 -I/usr/include/libbonobo-2.0 -I/usr/include/gnome-vfs-2.0 -I/usr/lib/gnome-vfs-2.0/include -I/usr/include/bonobo-activation-2.0 -I/usr/include/libxml2" "GNOME_LIBS = -Wl,--export-dynamic -pthread -L/usr/X11R6/%{_lib} -lgnomeui-2 -lSM -lICE -lbonoboui-2 -lxml2 -lpthread -lz -lgnome-2 -lpopt -lbonobo-2 -lgconf-2 -lgnomevfs-2 -lbonobo-activation -lORBit-2 %{lib_gthread} -lgnomecanvas-2 -lart_lgpl_2 %{lib_pangoft2} %{lib_gtk_x11} %{lib_gdk_x11} %{lib_atk} -lgdk_pixbuf-2.0 -lm %{lib_pangocairo} %{lib_pango} %{lib_cairo} %{lib_gobject} %{lib_gmodule} -ldl %{lib_glib}" "VTE_CFLAGS = -I$RPM_BUILD_ROOT/%{__frysk_includedir}/glib-2.0 -I$RPM_BUILD_ROOT/%{__frysk_libdir}/glib-2.0/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/gtk-2.0 -I/usr/include -I$RPM_BUILD_ROOT/%{__frysk_includedir}/pango-1.0 -I/usr/X11R6/include -I/usr/include/freetype2 -I/usr/include/freetype2/config -I$RPM_BUILD_ROOT/%{__frysk_libdir}/gtk-2.0/include -I$RPM_BUILD_DIR/%{__frysk_includedir}/atk-1.0 -I$RPM_BUILD_ROOT/%{__frysk_includedir}/cairo" "VTE_LIBS = -L/usr/X11R6/%{_lib} -lvte -lz -lncurses -lSM -lICE -lXft -lX11 -lfreetype -lXrender %{lib_gtk_x11} %{lib_pangoxft} %{lib_pangox} %{lib_fontconfig} %{lib_gdk_x11} %{lib_atk} %{lib_gdk_pixbuf} -lm %{lib_pangocairo} %{lib_cairo} %{lib_pangoft2} %{lib_pango} %{lib_gobject} %{lib_gmodule} -ldl %{lib_glib}" "JGJAVA_CFLAGS = %{JGJAVA_CFLAGS} -I $RPM_BUILD_ROOT/%{__frysk_includedir}"

CONFIG %{libvte_java} \
	--without-javadocs \
	%{__frysk_libs_configure}
BUILD %{libvte_java} %{libvte_java_makeflags}
INSTALL %{libvte_java}

%define VTE_JAVA_JAR $RPM_BUILD_ROOT/%{__frysk_datadir}/java/vte0.11.jar

#-----------antlr------------------------------------------

%if %{build_antlr}

%define antlr_builddir %{BUILDDIR}/%{antlr}
export ANTLR_JAR=$RPM_BUILD_ROOT/%{__frysk_datadir}/java/antlr.jar

CONFIG %{antlr} \
	--disable-python \
	--disable-csharp \
	--disable-cxx \
	--disable-examples \
	%{__frysk_libs_configure}
BUILD %{antlr} %{?_smp_mflags}
if INSTALL_P %{antlr} ; then
	install -d `dirname $ANTLR_JAR`
	install %{antlr_builddir}/antlr/antlr.jar $ANTLR_JAR
	INSTALLED %{antlr}
fi

%endif

#-----------jdom------------------------------------------

%define jdom_builddir %{BUILDDIR}/%{jdom}
export JDOM_JAR=$RPM_BUILD_ROOT/%{__frysk_datadir}/java/jdom.jar

mkdir -p %{jdom_builddir}
CONFIGURED %{jdom}

if BUILD_P %{jdom} ; then
	pushd %{jdom_builddir}
	rm -f BUILD.tmp
	echo '#!/bin/sh -xe' >> BUILD.tmp
	echo classdir=$PWD >> BUILD.tmp
	EXPORT >> BUILD.tmp
	echo '( cd ../../%{jdom} && ${JAVAC} -Ipackage -Isrc/java -O -g -d $classdir @jdom.files )' >> BUILD.tmp
	echo 'find * -name "*.class" -print | ${JAR} -@ -cf jdom.jar' >> BUILD.tmp
	chmod a+x BUILD.tmp
	mv BUILD.tmp BUILD.sh
	%{jdom_builddir}/BUILD.sh
	popd
	BUILT %{jdom}
fi

if INSTALL_P %{jdom} ; then
	install -d `dirname $JDOM_JAR`
	install %{jdom_builddir}/jdom.jar $JDOM_JAR
	INSTALLED %{jdom}
fi

#-----------frysk------------------------------------------

%if %{build_frysk}
%define frysk_builddir %{BUILDDIR}/%{frysk}

%define frysk_rpaths -Djava.library.path=%{__frysk_libdir}: -Wl,-rpath,%{__frysk_libdir}:

%define frysk_makeflags "FRYSK_GTK_CFLAGS = %{GTK_CFLAGS} %{ATK_CFLAGS} %{CAIRO_CFLAGS} %{PANGO_CFLAGS} %{GLIB_CFLAGS} %{GTK_CFLAGS} %{GLIB_JAVA_CFLAGS} %{GTKJAVA_CFLAGS}" "FRYSK_GTK_CLASSPATH = %{GTK2_JAR}:%{GLIB_JAVA_JAR}" "FRYSK_GTK_JARS = %{GTK2_JAR} %{GLIB_JAVA_JAR}" "FRYSK_GTK_LIBS = -L$RPM_BUILD_ROOT/%{__frysk_libdir} -lgtkjava -lcairojava -lgtk-x11-2.0 -lgdk-x11-2.0 -latk-1.0 -lgdk_pixbuf-2.0 -lm -lpangocairo-1.0 -lpangoft2-1.0 -lpango-1.0 -lcairo -lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0 -lglibjava" "FRYSK_GUI_JARS = %{GTK2_JAR} %{GLADE_JAR} %{GLIB_JAVA_JAR} %{VTE_JAVA_JAR}" "FRYSK_GUI_CFLAGS = %{GTK_CFLAGS} %{ATK_CFLAGS} %{CAIRO_CFLAGS} %{PANGO_CFLAGS} %{GLIB_CFLAGS} %{GTK_CFLAGS} %{GLIB_JAVA_CFLAGS} %{GTKJAVA_CFLAGS}" "FRYSK_GUI_LIBS = -L$RPM_BUILD_ROOT/%{__frysk_libdir} -lgtkjava -lcairojava -lglade-2.0 -lgladejava -lvtejava -lgtk-x11-2.0 -lgdk-x11-2.0 -latk-1.0 -lgdk_pixbuf-2.0 -lm -lpangocairo-1.0 -lpangoft2-1.0 -lpango-1.0 -lcairo -lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0 -lglibjava" "frysk_bindir_frysk_LDFLAGS = --main=frysk.bindir.frysk %{frysk_rpaths}" "frysk_bindir_fstack_LDFLAGS = --main=frysk.bindir.fstack %{frysk_rpaths}" "frysk_bindir_ftrace_LDFLAGS = --main=frysk.bindir.ftrace %{frysk_rpaths}"

export FRYSK_GTK_JARS="XXX: ignored"
export FRYSK_GUI_JARS="XXX: ignored"

CONFIG %{frysk} \
	%{__frysk_configure}
BUILD %{frysk} %{?_smp_mflags} %{frysk_makeflags}
INSTALL %{frysk} %{frysk_makeflags}
%endif

#-----------done------------------------------------------

%post

%{_bindir}/frysk-update-pango-modules
%{_bindir}/frysk-update-gdk-pixbuf-loaders
%{_bindir}/frysk-update-gtk-immodules

/sbin/ldconfig

%postun

/sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
/usr/bin/*
%if %{build_frysk}
/usr/%{_lib}/libEggTrayIcon.so
/usr/%{_lib}/libfrysk-*.so
/usr/%{_lib}/libftk*.so
/usr/share/java/frysk-*.jar
/usr/share/java/ftk.jar
%endif
/usr/share/man/*/frysk-*
/usr/include/frysk/*
/usr/%{_lib}/frysk/*
/usr/share/frysk/*
/etc/frysk/*
/usr/share/applications/frysk.desktop
/usr/share/pixmaps/fryskTrayIcon48.png

%changelog
* Sat Jan 21 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.22-0.EL4.0
- Import glib 2.9.4.tar.bz2, atk 1.11.2.tar.bz2, and frysk
  0.0.1.2006.01.22.
- Add/update gtk+-2.8.10-set-invisible-char-to-bullet.patch,
  fontconfig-2.3.93-defaultconfig.patch, and 50-no-hint-fonts.conf.
- Add frysk.desktop, and fryskTrayIcon48.png to -files.

* Sat Jan 21 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.9
- Replace macros gccp, and gccs with frysk_gcc_prefix and
  frysk_gcc_suffix.  Update EXPORT function to use.
- In EXPORT, for ppc64, append -mminimal-toc to all all compiler
  environment variables.
- Add macros build_frysk, and build_antlr.  Use instead of
  architecture test.

* Sat Jan 21 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.8
- For antlr, update config.guess and config.sub; problem reported by
  Wu Zhou <woodzltc@cn.ibm.com>

* Sat Jan 21 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.7
- Drop update-scripts.tar.gz and update-scripts-frysk.patch.
- Replace -post and -postun steps generating pango.modules and
  gdk-pixbuf.loaders with the scripts frysk-update-gdk-pixbuf-loaders,
  frysk-update-gtk-immodules, and frysk-update-pango-modules run from
  -post, and generated by MKUPDATE.

* Sat Jan 21 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.6
- Rename lib_pangoft to lib_pangoft2.
- Add lib_pangoft2 to libglade2_makeflags.

* Fri Jan 20 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.5
- Fix typo, point lib_gdk_xll at libgdk-xll and not libgtk-xll.
- Add lib_gtk_x11 to libglade2_makeflags.

* Fri Jan 20 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.4
- Add shell functions MKSCRIPT and ECHO_CMD for creating a shell
  script.  In CONFIG, BUILD, and INSTALL use these to create a shell
  script containing all the config, build or install information.
  Run.

* Thu Jan 19 2006 Diego Novillo <dnovillo@redhat.com> 0.0.1.2006.01.13-0.EL4.3
- Use %{_target_platform} instead of i686-redhat-linux-gnu.

* Tue Jan 17 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.2
- Add gtk+-2.8.6-frysk-theme-fix.patch; partial fix to lack of themes.

* Tue Jan 17 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.1
- Import new packages and patches from FC-5: atk-1.11.0, cairo-1.11.0,
  fontconfig-2.3.93, glib-29.3, gtk+-2.8.10, libglade-java-2.12.1,
  pango-1.11.2.  For pango, add XFT_LIBS, XFT_CFLAGS to
  pango_makeflags.  For libglade, add --without-gnome to configure
  line.  For fontconfig, also install config files.
- Use /%{_lib}, instead of /lib, in XFT_LIBS library paths.
- Don't build on x86-64 for now (sorry).

* Fri Jan 13 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2006.01.13-0.EL4.0
- Import frysk-0.0.1.2006.01.13.tar.bz2
- Revamp -prep and -bupid sections: unpack glib-java early so its m4
  macros are available; eliminate jg-common; -setup all tar balls
  under $RPM_BUILD_DIR; change BUILDDIR to $RPM_BUILD_DIR/build-...;
  in -setup remove entire BUILDDIR.
- Update __frysk_configure and __frysk_libs_configure to explicitly
  specify all paths (especially --mandir which was wrong).  Where
  applicable use _sysconfigdir, _bindir, et.al. instead of
  _frysk_sysconfigdir, et.al. In -files, replace /usr/man/*/frysk-*
  with /usr/share/man/*/frysk-*.
- Rename libglade to libglade2 to better match rpm name.
- Define gccp[refix] and gccs[uffix], use in hardwired GCC paths.
  Pass FRYSK_GTK_... instead of FRYSK_IMPORTS_ make file variables to
  frysk's make.

* Tue Jan 10 2006 Diego Novillo <dnovillo@redhat.com> 0.0.1.2005.12.14.15.12-0.EL4.6
- Add gtk+-libgdk-lm.patch.
- Add support for building support libraries on x86_64.
- Disable main frysk build on x86_64.

* Thu Jan 5 2006 Andrew Cagney <cagney@redhat.com> 0.0.1.2005.12.14.15.12-0.EL4.5
- In build section, delete all the INSTALLED markers.

* Thu Dec 22 2005 Adam Jocksch <ajocksch@redhat.com> 0.0.1.2005.12.14.15.12-0.EL4.4
- updated libgtk-java tarball, bumped release.

* Mon Dec 19 2005 Peter Jones <pjones@redhat.com> 0.0.1.2005.12.14.15.12-0.EL4.3
- bumped release to build in rhel4u3 tree

* Mon Dec 19 2005 Roland McGrath <roland@redhat.com> - 0.0.1.2005.12.14.15.12-0.EL4.2
- Avoid improper provides/requires in rpm.

* Wed Dec 14  2005 Andrew Cagney <cagney@redhat.com> 0.0.1.2005.12.14.15.12-0.EL4.1
- Import frysk-0.0.1.2005.12.14.15.12.tar.bz2.
- Add /usr/lib/libftk*.so, and /usr/share/ftk.jar to files.

* Tue Dec 13  2005 Andrew Cagney  <cagney@redhat.com>  0.0.0.20051211.1-0.EL4.6
- Add dependencies on autoconf, automake, and automake17.

* Tue Dec 13  2005 Rick Moseley  <rmoseley@redhat.com>  0.0.0.20051211.1-0.EL4.5
- Add patch to the jdom source to fix 4.0.2-12 compiler error

* Mon Dec 12  2005 Rick Moseley  <rmoseley@redhat.com>  0.0.0.20051211.1-0.EL4.4
- Add patches to correct jg-common/glib-java macro file errors
- Add patch to correct frysk-imports/test/Makefile.am error
- Add GIJ variable to exports

* Sun Dec 11  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051211.1-0.EL4.3
- Add commands to generate / remove the files
  pango/i686-redhat-linux-gnu/pango.modules, and
  gtk-2.0/gdk-pixbuf.loaders during post and postun phases.

* Sun Dec 11  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051211.1-0.EL4.2
- Bum version number.

* Sun Dec 11  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051211.1-0.EL4.1
- Update pango-skip-cairo-check.patch, leave in definition of
  HAVE_CAIRO_FREETYPE.

* Sun Dec 11  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051211.1-0.EL4.0
- Set JV_SCAN.
- Import 0.0.0.20051211.1.
- Replace CONFIGURE with CONFIG; generates a CONFIG.sh script and runs
  that.
- For JDOM, generate a BUILD.sh script and run that.

* Sun Dec 10  2005 Rick Moseley  <rmoseley@redhat.com>  0.0.0.20051209.1-0.EL4.4
- added "BuildRequires: gtk-doc" under the gtk2 section(BZ 2028)

* Sat Dec 10  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051209-0.EL4.3
- Add -lpangoft2 to frysk_makeflags.
- Add frysk_bindir_frysk_LDFLAGS, frysk_bindir_ftrace_LDFLAGS, and
  frysk_bindir_fstack_LDFLAGS to frysk_makeflags.  XXX: Needs a better
  way.

* Sat Dec 10  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051209-0.EL4.2
- Add *-pkg-dir.patchs, add datadir to, and fix classpath and
  macro_dir in the PACKAGE.pc, add file.
- For java packages, where needed run aclocal with -I
  ../jg-common/macros, and -I ../libgtk-java/macros.

* Fri Dec 9  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051209-0.EL4.1
- Import 0.0.0.20051209 tar ball.
- Add frysk-head.patch.  Run frysk's autogen.sh.

* Fri Dec 9  2005 Rick Moseley  <rmoseley@redhat.com>  0.0.0.20051202.1-0.EL4.5
- added "export CC=/usr/bin/gcc4" so gcc4 compiler will be used.

* Thu Dec 8  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.5
- Move --datadir to __frysk_libs_config.

* Thu Dec 8  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.4
- Delete buildroot hack.
- Bump version number.

* Thu Dec 8  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Renamed TextMarkFactoryFix to libgtk-java-TextMarkFactoryFix.

* Thu Dec 8  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Delete build_failed check.

* Wed Dec 7  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Rename GTK2_CFLAGS to GTK_CFLAGS, avoid confusion.
- Delete remaining build_*, and install_* flags.
- Enable antlr, jdom, and frysk.
- Delete /usr/share/java/frysk-*.jar from files section.

* Wed Dec 7  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Fixed typo in declaration of libpangoft.
- Added patch to fix libgtk-java TextMark problem (java-gnome bug #323508).

* Wed Dec 7  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Changed references to .la files away from the .libs directories in glib-java
  and libgtk-java

* Wed Dec 7  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Add CONFIGURE, BUILD, and INSTALL shell functions to install - only
  do the actioin if it hasn't been performed before.  Delete
  corresponding build_* and install_* macros.
- Rename __frysk_gtk_configure to __frysk_libs_configure.

* Wed Dec 7  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Added defs for libpango{ft|x|xft} to pango build section, updated all
  relevant paths.

* Wed Dec 7  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Rename libglade (the second definition) to lib_glade, ditto for all
  other macro's defining a .la path; stop's macro recursion.

* Wed Dec 7  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Updated versions of libgtk-java, glib-java, and cairo-java to latest official
  releases, removed old versions.

* Wed Dec 7  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Enabled build of libvte-java.

* Tue Dec 6  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Added libgtkjni, libgtk_java definition to libgtk-java section.
- Added libgtk_x11 definition to gtk2 section.
- Enabled libglade-java build.

* Tue Dec 6  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Added lib* definitions for cairo-java.
- Added cflags definition for cairo-java.
- libgtk-java build enabled, libgtk_java_makeflags set.

* Tue Dec 6  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Add DEP_LIBS to atk_makeflags.
- Add lib* definitions for all .la files.
- Enable gtk2 and libglade.
- Explicitly specify the MAKE *_LIB variable in the *_makeflags line.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Move atk's build code to before gtk, enable.
- Pass location of atk to libglade and gtk's make.
- Disable gtk, sigh.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Add libglade-atk-ver-1-8.patch, don't enable.
- Define GTK2_CFLAGS, and GTK2_LIBS.
- Define libglade_makeflags, pass to libglade's make.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Print RPM_BUILD_ROOT
- Enable gtk2; added libgthread-2.0.la to GLIB_LIBS, and
  GDK_PIXBUF_XLIB_DEP_CFLAGS to gtk2_makeflags.

* Mon Dec 5  2005 Adam Jocksch <ajocksch@redhat.com>  0.0.0.20051202.1-0.EL4.3
- cairo-java is now being built.

* Mon Dec 5  2005 Adam Jocksch <ajocksch@redhat.com>  0.0.0.20051202.1-0.EL4.3
- Got glib-java section building.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Re-order build list, build for gtk, cairo, glib, build java bindings
  immediatly after c library.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Disable atk.
- Pass pango_makeflags to pango's make install.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Define SRCDIR, DESTDIR, and BUILDDIR.  Use throughout.
- Re-indent all if/fi code.

* Mon Dec 5  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Fix gtk+-skip-glib-check.patch to patch m4macros/gtk-2.0.m4 instead
  of a generated file.  Use --disable-glibtest.
- Add gtk+-skip-pango-check.patch, to disable pango runtime test.
- For pango, run autoconf, and automake as part of setup.
- Cleanup all makefile parameters (GLIB_CFLAGS, et.al.) so that they
  are defined consistently.
- Define pango_makeflags, pass to pango's make forcing it to look in
  the build tree for headers and libraries.  Ditto for gtk2_makeflags.

* Sun Dec 4  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Add gtk+-skip-glib-check.patch; skips over the glib validation step.
- Add pango-skip-cairo-check.patch; skips over cairo validation step.
- For pango, override glib, cairo, and fontconfig flags.

* Sat Dec 3  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Add install_* flags to control install.
- Run autoconf et.al. as part of setup.
- Do everything in install (outch!).
- Pass %{?_smp_mflags} to make commands.
- Point PKG_CONFIG_PATH, and LD_LIBRARY_PATH at RPM_BUILD_ROOT.
- Update list of files.
- Delete the install-root as part of build.
- Pass DESTDIR to all make install commands.
- Always define ANTLR_JAR and JDOM_JAR variables.
- Enable build of frysk.
- Define glib_cflags, glib_libs, cairo_cflags, and pass where needed.

* Fri Dec 2  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.3
- Disable frysk part of build, causes internal compiler error.

* Fri Dec 2  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.2
- Add requirements for gcc4-java and gcc4-c++

* Fri Dec 2  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.1
- Add more installed files.

* Fri Dec 2  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051202.1-0.EL4.1
- Wrap every step in if%{build...}.
- Bump version to 0.0.0.20051202.1.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051201.1-0.EL4.1
- Use Adam's --prefix=... trick to get all of the gnome stuff to build.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051201.1-0.EL4.1
- Fix package config path (/usr/lib) to match.  Add conditional build variables.

* Thu Dec 1  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051201.1-0.EL4.1
- Various typo-fixes.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051201.1-0.EL4.1
- Update frysk tar ball, has JDOM configury enabled.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Build jdom, define JDOM_JAR.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Import jdom sources.

* Thu Dec 1  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Added correct prefix for configure, testing install prefix.

* Thu Dec 1  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Added build sections for frysk prerequisites.

* Thu Dec 1  2005 Adam Jocksch <ajocksch@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Added paths for temporary install directory.
- Added BuildRequires and Requires for libvte-java.

* Thu Dec 1  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Add libvte-java to sources and unpack.

* Wed Nov 30  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Unpack and patch all tar balls; frysk being put in a sub-directory.

* Wed Nov 30  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.2
- Add in initial full list of build dependencies, source files and
  patches.

* Wed Nov 30  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.1
- Update to 0.0.0.20051128.2, pick up fix for JAVAC=<absolute-path-bug>.
- Delete stray ^L.

* Wed Nov 30  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4.1
- Make environment variable paths absolute, hack around AC_PATH_PROG
  bug.

* Tue Nov 29  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4
- Change frysk to a .bz2 file.
- Add BuildRequires gcc4 et.al.
- Add install.and files rules.
- Update antlr.patch to handle/prefer gcc4.

* Mon Nov 28  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051128.2-0.EL4
- Bump frysk version to 0.0.0.20051128.2
- Fill out code for building antlr.jar, set ANTLR_JAR environment variable.
- Add initial logic for building frysk.

* Mon Nov 28  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051116-0.EL4
- Add prep and build rules to build antlr, add antlr.patch.

* Mon Nov 28  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051116-0.EL4
- Add antlr-2.7.5.tar.gz.

* Mon Nov 28  2005 Andrew Cagney <cagney@redhat.com> 0.0.0.20051116-0.EL4
- Rebirth, created from shell of devel frysk.spec.

* Wed Oct 26  2005 Igor Foox <ifoox@redhat.com> 0.0-1
- Birth.
